@@ -17,7 +17,7 @@ my %CFG = gcr_config();
 
 sub opt_spec {
     return (
-        #    ['noop',       "Take no recorded actions."],
+        #    ['noop',       "Just run a sample selection."],
     );
 }
 
@@ -62,7 +62,7 @@ sub execute {
         "# Lines begining with a '#' will be skipped.",
     ;
     close $fh;
-    gcr_open_editor( modify => $tmpfile );
+    gcr_open_editor( comment => $tmpfile );
     # should have contents
     open($fh,"<", $tmpfile) or die "Tempfile($tmpfile) problems: $!";
     my @content = ();
@@ -117,7 +117,7 @@ Git::Code::Review::Command::comment - Comment on a commit in the audit
 
 =head1 VERSION
 
-version 0.3.1
+version 0.1
 
 =head1 AUTHOR
 
